/* userDialog.js
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

/* exported ModalUserDialog */

const Gettext = imports.gettext;
const Signals = imports.signals;

const { Clutter, Gio, GObject, Pango, St } = imports.gi;

const ExtensionUtils = imports.misc.extensionUtils;

const Dialog = imports.ui.dialog;
const ModalDialog = imports.ui.modalDialog;

const Me = ExtensionUtils.getCurrentExtension();

const _ = Gettext.domain(Me.metadata['gettext-domain']).gettext;

const clearRecentDocumentsDialogContent = {
    title: _("Clear the list of last used documents?"),
    description: _("If you clear the list of last used documents, you clear the following:\n\u2022 All items from the Places \u2192 Last used documents menu item\n\u2022 All items from the last used documents list in all applications"),
    label: _("Clear list"),
};

const deleteTrashEntryDialogContent = {
    title: _("If you delete an object, it will be permanently lost."),
    description: value => {
        return _("Are you sure you want to permanently delete '%s' from the trash?").format(value);
    },
    label: _("Delete Permanently"),
};

const ejectVolumeDialogContent = {
    title: _("Eject the selected volume?"),
    description: value => {
        return _("Volume: %s").format(value);
    },
    label: _("Eject"),
};

const emptyTrashDialogContent = {
    title: _("Empty all items from Trash?"),
    description: _("All items in the Trash will be permanently deleted."),
    label: _("Empty the Trash"),
};

const removeRecentDocumentDialogContent = {
    title: _("Remove the selected document?"),
    description: value => {
        return _("Are you sure you want to remove '%s' from the list of last used documents?").format(value);
    },
    label: _("Remove"),
};

const DialogContent = {
    'clearRecentDocuments': clearRecentDocumentsDialogContent,
    'deleteTrashEntry': deleteTrashEntryDialogContent,
    'ejectVolume': ejectVolumeDialogContent,
    'emptyTrash': emptyTrashDialogContent,
    'removeRecentDocument': removeRecentDocumentDialogContent,
};

var ModalUserDialog = GObject.registerClass(
class ModalUserDialog extends ModalDialog.ModalDialog {
    _init(params) {
        super._init({ styleClass: 'modal-user-dialog' });
        let { title, description, label } = DialogContent[params.content];
        let content = new Dialog.MessageDialogContent({
            title: title,
            description: params.value ? description(params.value) : description,
        });
        this.contentLayout.add_actor(content);
        this.setButtons([
            { label: _("Cancel"), action: () => { this.close(); }, key: Clutter.Escape },
            { label: label, action: () => { this.close(); params.callback(); } },
        ]);
    }
});
